Processor.processor.Listener.on\_receiver\_loop\_completed
==========================================================

.. currentmodule:: Processor.processor

.. automethod:: Listener.on_receiver_loop_completed